/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.taxonomy;

import it.tidalwave.bluebill.mobile.preferences.TaxonomyPreferences;
import javax.annotation.Nonnull;
import javax.inject.Provider;
import java.util.Locale;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.netbeans.util.Locator;
import it.tidalwave.bluebill.taxonomy.mobile.Taxon;
import it.tidalwave.bluebill.mobile.preferences.NameMatcher;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class TaxonFilter
  {
    @Nonnull
    private final Provider<TaxonomyPreferences> preferences = Locator.createProviderFor(TaxonomyPreferences.class);

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public boolean accepts (final @Nonnull Taxon taxon, final @Nonnull CharSequence match)
      {
        final NameMatcher nameMatcher = preferences.get().getNameMatcher();
//        logger.finest("accepts: %s", nameMatcher);

        if (matchesLocalizedNames(taxon, match, nameMatcher))
          {
            return true;
          }

        if (preferences.get().isScientificNamesRenderingEnabled())
          {
            return matchesScientificName(taxon, match, nameMatcher);
          }

        return false;
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    private boolean matchesLocalizedNames (final @Nonnull Taxon taxon,
                                           final @Nonnull CharSequence match,
                                           final @Nonnull NameMatcher nameMatcher)
      {
        for (final Locale locale : preferences.get().getTaxonomyLocales())
          {
            try
              {
                if (nameMatcher.matches(taxon.getDisplayName(locale), match, locale))
                  {
                    return true;
                  }
              }
            catch (NotFoundException e)
              {
                // never mind
              }
          }

        return false;
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    private boolean matchesScientificName (final @Nonnull Taxon taxon,
                                           final @Nonnull CharSequence match,
                                           final @Nonnull NameMatcher nameMatcher)
      {
        return nameMatcher.matches(taxon.getScientificName(), match, Locale.ENGLISH);
      }
  }
