/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.taxonomy.impl;

import javax.annotation.Nonnull;
import javax.inject.Provider;
import java.util.List;
import java.util.Locale;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.role.PlainTextRenderable;
import it.tidalwave.role.spi.StringRenderableSupport;
import it.tidalwave.netbeans.util.Locator;
import it.tidalwave.bluebill.mobile.preferences.TaxonomyPreferences;
import it.tidalwave.bluebill.taxonomy.mobile.Taxon;
import lombok.RequiredArgsConstructor;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@RequiredArgsConstructor
public class TaxonPlainTextRenderable extends StringRenderableSupport implements PlainTextRenderable
  {
    private final Provider<TaxonomyPreferences> preferences = Locator.createProviderFor(TaxonomyPreferences.class);
    
    @Nonnull
    private final Taxon taxon;
    
    @Nonnull
    public String render (final @Nonnull Object... args)
      {
        final StringBuilder buffer = new StringBuilder();
        String separator = "";
        final List<Locale> taxonLocales = preferences.get().getTaxonomyLocales();

        for (final Locale locale : taxonLocales)
          {
            try
              {
                buffer.append(separator).append(taxon.getDisplayName(locale));
                separator = ", ";
              }
            catch (NotFoundException e)
              {
                // a localized name not available, just ignore it
              }
          }

        if (preferences.get().isScientificNamesRenderingEnabled())
          {
            buffer.append(" (").append(taxon.getScientificName()).append(")");
          }

        return buffer.toString();
      }    
  }
